/****************************************************************************
* VCGLib                                                            o o     *
* Visual and Computer Graphics Library                            o     o   *
*                                                                _   O  _   *
* Copyright(C) 2004-2012                                           \/)\/    *
* Visual Computing Lab                                            /\/|      *
* ISTI - Italian National Research Council                           |      *
*                                                                    \      *
* All rights reserved.                                                      *
*                                                                           *
* This program is free software; you can redistribute it and/or modify      *
* it under the terms of the GNU General Public License as published by      *
* the Free Software Foundation; either version 2 of the License, or         *
* (at your option) any later version.                                       *
*                                                                           *
* This program is distributed in the hope that it will be useful,           *
* but WITHOUT ANY WARRANTY; without even the implied warranty of            *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
* GNU General Public License (http://www.gnu.org/licenses/gpl.txt)          *
* for more details.                                                         *
*                                                                           *
****************************************************************************/
/*! \file trimesh_base.cpp
\ingroup code_sample

\brief the minimal example of using the lib

This file contain a minimal example of the library, showing how to load a mesh and how to compute per vertex normals on it.

*/

#include<vcg/complex/complex.h>
#include<wrap/io_trimesh/import_obj.h>
#include<wrap/io_trimesh/export_obj.h>
#include<vcg/complex/algorithms/update/topology.h>
#include<vcg/complex/algorithms/update/normal.h>

class MyVertex; class MyEdge; class MyFace;
struct MyUsedTypes : public vcg::UsedTypes<vcg::Use<MyVertex>   ::AsVertexType,
                                           vcg::Use<MyEdge>     ::AsEdgeType,
                                           vcg::Use<MyFace>     ::AsFaceType>{};

class MyVertex  : public vcg::Vertex< MyUsedTypes, vcg::vertex::Coord3f, vcg::vertex::Normal3f, vcg::vertex::BitFlags  >{};
class MyFace    : public vcg::Face<   MyUsedTypes, vcg::face::FFAdj,  vcg::face::VertexRef, vcg::face::WedgeTexCoord2f, vcg::face::BitFlags > {};
class MyEdge    : public vcg::Edge<   MyUsedTypes> {};

class MyMesh    : public vcg::tri::TriMesh< std::vector<MyVertex>, std::vector<MyFace> , std::vector<MyEdge>  > {};
using namespace vcg;
int main( int argc, char **argv )
{
  if(argc<2)
  {
    printf("Usage trimesh_base <meshfilename.obj>\n");
    return -1;
  }
  MyMesh m;
  MyMesh t;

  int loadedmask;
  int ret = tri::io::ImporterOBJ<MyMesh>::Open(m,argv[1],loadedmask);
  if(ret != tri::io::ImporterOBJ<MyMesh>::E_NOERROR)
  {
    printf("unable to open file %s : %s \n",argv[1], tri::io::ImporterOBJ<MyMesh>::ErrorMsg(ret));

  }
  printf( "Mesh %s has %i vert and %i faces\n", argv[1], m.VN(), m.FN() );

  for(MyMesh::FaceIterator fi=m.face.begin();fi!=m.face.end();++fi)
  {
    Point3f t0(fi->WT(0).u(),fi->WT(0).v(),0);
    Point3f t1(fi->WT(1).u(),fi->WT(1).v(),0);
    Point3f t2(fi->WT(2).u(),fi->WT(2).v(),0);

    tri::Allocator<MyMesh>::AddFace(t,t0,t1,t2);
  }

  tri::io::ExporterOBJ<MyMesh>::Save(t,"out.obj",tri::io::Mask::IOM_WEDGTEXCOORD);
  return 0;
}













